#include <SDL/SDL.h>

#include <assert.h>
#include <err.h>
#include <stdint.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "error.h"
#include "images.h"

static struct
{
  char name[64];
  uint32_t width;
  uint32_t height;
} infos[1];

static SDL_Surface* surfaces[4096];
static uint32_t image_count = 1;

#if SDL_BYTEORDER == SDL_LIL_ENDIAN
#define swapu32(v)
#else
#define swapu32(v) do { v = (v >> 24) | ((v & 0xFF0000) >> 8) | ((v & 0xFF00) << 8) | (v << 24); } while(0);
#endif

void load_images()
{
  uint32_t i, x, y;
  SDL_Surface* s;

  assert(image_count <= sizeof(surfaces) / sizeof(surfaces[0]));

  for(i = 0; i < image_count; ++i)
  {
    unsigned char* dest;

    if(surfaces[i])
      continue;

    strcpy(infos[i].name, "background.png");
    infos[i].width = 640;
    infos[i].height = 480;

#if SDL_BYTEORDER == SDL_LIL_ENDIAN
    s = SDL_CreateRGBSurface(SDL_SRCALPHA, infos[i].width, infos[i].height, 32, 0x000000ff, 0x0000ff00, 0x00ff0000, 0xff000000);
#else
    s = SDL_CreateRGBSurface(SDL_SRCALPHA, infos[i].width, infos[i].height, 32, 0xff000000, 0x00ff0000, 0x0000ff00, 0x000000ff);
#endif

    surfaces[i] = s;

    SDL_LockSurface(s);

    for(y = 0; y < s->h; ++y)
    {
      dest = (unsigned char*) s->pixels + y * s->pitch;

      for(x = 0; x < s->w * 4; x += 4)
      {
        dest[x] = images[y * s->w * 4 + x];
        dest[x + 1] = images[y * s->w * 4 + x + 1];
        dest[x + 2] = images[y * s->w * 4 + x + 2];
        dest[x + 3] = images[y * s->w * 4 + x + 3];
      }
    }

    SDL_UnlockSurface(surfaces[i]);
  }
}

SDL_Surface* get_image(const char* name)
{
  uint32_t i;

  for(i = 0; i < image_count; ++i)
  {
    if(!strcmp(infos[i].name, name))
      return surfaces[i];
  }

  return 0;
}
